# -*- coding: UTF-8 -*-

import base64

import sys

PY3 = sys.version_info[0] == 3


class AppSettings(object):
    """
    This class is to storage basic app_type, app_id, app_secret for application.
    """

    def __init__(self, app_type, app_id, app_secret, verification_token='', encrypt_key='', help_desk_id='',
                 help_desk_token=''):
        # type: (str, str, str, str, str, str, str) -> None
        self.app_type = app_type
        self.app_id = app_id
        self.app_secret = app_secret
        self.verification_token = verification_token
        self.encrypt_key = encrypt_key
        self.help_desk_id = help_desk_id
        self.help_desk_token = help_desk_token

    def get_help_desk_authorization(self):
        # type: () -> str
        if self.help_desk_id == '' or self.help_desk_token == '':
            return ''
        token = self.help_desk_id + ':' + self.help_desk_token
        if PY3:
            return base64.b64encode(token.encode('utf-8')).decode('utf-8')
        else:
            return base64.b64encode(token)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.access_records = AccessRecordService(self)
        self.users = UserService(self)
        self.devices = DeviceService(self)
        self.access_record_access_photos = AccessRecordAccessPhotoService(self)
        self.user_faces = UserFaceService(self)
        



class AccessRecordService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> AccessRecordListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return AccessRecordListReqCall(self, request_opts=request_opts)


class UserService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def patch(self, body, tenant_key=None, timeout=None):
        # type: (User, str, int) -> UserPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserPatchReqCall(self, body, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> UserGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserGetReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> UserListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserListReqCall(self, request_opts=request_opts)


class DeviceService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DeviceListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DeviceListReqCall(self, request_opts=request_opts)


class AccessRecordAccessPhotoService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get(self, tenant_key=None, response_stream=None, timeout=None):
        # type: (str, Union[None, IO], int) -> AccessRecordAccessPhotoGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if response_stream is not None:
            request_opts += [set_response_stream(response_stream)]

        return AccessRecordAccessPhotoGetReqCall(self, request_opts=request_opts)


class UserFaceService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get(self, tenant_key=None, response_stream=None, timeout=None):
        # type: (str, Union[None, IO], int) -> UserFaceGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if response_stream is not None:
            request_opts += [set_response_stream(response_stream)]

        return UserFaceGetReqCall(self, request_opts=request_opts)

    def update(self, tenant_key=None, timeout=None):
        # type: (str, int) -> UserFaceUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return UserFaceUpdateReqCall(self, request_opts=request_opts)



class AccessRecordListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AccessRecordService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_page_size(self, page_size):
        # type: (int) -> AccessRecordListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> AccessRecordListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_from(self, from_):
        # type: (int) -> AccessRecordListReqCall
        self.query_params['from'] = from_
        return self

    def set_to(self, to):
        # type: (int) -> AccessRecordListReqCall
        self.query_params['to'] = to
        return self

    def set_device_id(self, device_id):
        # type: (int) -> AccessRecordListReqCall
        self.query_params['device_id'] = device_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> AccessRecordListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[AccessRecordListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/acs/v1/access_records', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=AccessRecordListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AccessRecordAccessPhotoGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AccessRecordAccessPhotoService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_access_record_id(self, access_record_id):
        # type: (int) -> AccessRecordAccessPhotoGetReqCall
        self.path_params['access_record_id'] = access_record_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_is_response_stream()]
        req = APIRequest('/open-apis/acs/v1/access_records/:access_record_id/access_photo', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DeviceListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DeviceService, List[Any]) -> None

        self.service = service
        

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[DeviceListResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/acs/v1/devices', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=DeviceListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (UserService, User, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserPatchReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserPatchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/acs/v1/users/:user_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserGetReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/acs/v1/users/:user_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=UserGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_page_size(self, page_size):
        # type: (int) -> UserListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> UserListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[UserListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/acs/v1/users', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=UserListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserFaceGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserFaceService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id(self, user_id):
        # type: (str) -> UserFaceGetReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_is_cropped(self, is_cropped):
        # type: (bool) -> UserFaceGetReqCall
        self.query_params['is_cropped'] = is_cropped
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserFaceGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        self.request_opts += [set_is_response_stream()]
        req = APIRequest('/open-apis/acs/v1/users/:user_id/face', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class UserFaceUpdateReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (UserFaceService, List[Any]) -> None

        self.service = service
        self.body = FormData()
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_files(self, files):
        # type: (IO[Any]) -> UserFaceUpdateReqCall
        self.body.add_file('files', FormDataFile(files))
        return self

    def set_file_type(self, file_type):
        # type: (str) -> UserFaceUpdateReqCall
        self.body.add_param('file_type', file_type)
        return self

    def set_file_name(self, file_name):
        # type: (str) -> UserFaceUpdateReqCall
        self.body.add_param('file_name', file_name)
        return self

    def set_user_id(self, user_id):
        # type: (str) -> UserFaceUpdateReqCall
        self.path_params['user_id'] = user_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> UserFaceUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/acs/v1/users/:user_id/face', 'PUT', [ACCESS_TOKEN_TYPE_TENANT], self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import Callable

from ....config import Config
from ....context import Context
from ....event.event import set_event_callback

from .model import *


class AwemeUserBindedAccountEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, AwemeUserBindedAccountEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, AwemeUserBindedAccountEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, AwemeUserBindedAccountEvent], Any]) -> None
        handler = AwemeUserBindedAccountEventHandler(callback)
        set_event_callback(conf, "aweme_ecosystem.aweme_user.binded_account_v1",
                          handler.handle, clazz=AwemeUserBindedAccountEvent)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr





@to_json_decorator
@attr.s
class ImageBasicRecognizeReqBody(object):
    image = attr.ib(type=str, default=None, metadata={'json': 'image'})


@attr.s
class ImageBasicRecognizeResult(object):
    text_list = attr.ib(type=List[str], default=None, metadata={'json': 'text_list'})


# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Avatar(object):
    avatar_origin = attr.ib(type=str, default=None, metadata={'json': 'avatar_origin'})
    avatar_72 = attr.ib(type=str, default=None, metadata={'json': 'avatar_72'})
    avatar_240 = attr.ib(type=str, default=None, metadata={'json': 'avatar_240'})
    avatar_640 = attr.ib(type=str, default=None, metadata={'json': 'avatar_640'})


@to_json_decorator
@attr.s
class Tenant(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    display_id = attr.ib(type=str, default=None, metadata={'json': 'display_id'})
    tenant_tag = attr.ib(type=int, default=None, metadata={'json': 'tenant_tag'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    avatar = attr.ib(type=Avatar, default=None, metadata={'json': 'avatar'})




@attr.s
class TenantQueryResult(object):
    tenant = attr.ib(type=Tenant, default=None, metadata={'json': 'tenant'})


# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import Callable

from ....config import Config
from ....context import Context
from ....event.event import set_event_callback

from .model import *


class CalendarChangedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, CalendarChangedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, CalendarChangedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, CalendarChangedEvent], Any]) -> None
        handler = CalendarChangedEventHandler(callback)
        set_event_callback(conf, "calendar.calendar.changed_v4",
                          handler.handle, clazz=CalendarChangedEvent)


class CalendarAclCreatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, CalendarAclCreatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, CalendarAclCreatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, CalendarAclCreatedEvent], Any]) -> None
        handler = CalendarAclCreatedEventHandler(callback)
        set_event_callback(conf, "calendar.calendar.acl.created_v4",
                          handler.handle, clazz=CalendarAclCreatedEvent)


class CalendarAclDeletedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, CalendarAclDeletedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, CalendarAclDeletedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, CalendarAclDeletedEvent], Any]) -> None
        handler = CalendarAclDeletedEventHandler(callback)
        set_event_callback(conf, "calendar.calendar.acl.deleted_v4",
                          handler.handle, clazz=CalendarAclDeletedEvent)


class CalendarEventChangedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, CalendarEventChangedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, CalendarEventChangedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, CalendarEventChangedEvent], Any]) -> None
        handler = CalendarEventChangedEventHandler(callback)
        set_event_callback(conf, "calendar.calendar.event.changed_v4",
                          handler.handle, clazz=CalendarEventChangedEvent)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
from ....event.model.event import *
import attr




@to_json_decorator
@attr.s
class Feature(object):
    card = attr.ib(type=int, default=None, metadata={'json': 'card'})
    face_uploaded = attr.ib(type=bool, default=None, metadata={'json': 'face_uploaded'})


@to_json_decorator
@attr.s
class User(object):
    feature = attr.ib(type=Feature, default=None, metadata={'json': 'feature'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})


@to_json_decorator
@attr.s
class UserId(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})


@to_json_decorator
@attr.s
class Device(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["device_id"])
    device_id = attr.ib(type=int, default=None, metadata={'json': 'device_id'})
    device_name = attr.ib(type=str, default=None, metadata={'json': 'device_name'})
    device_sn = attr.ib(type=str, default=None, metadata={'json': 'device_sn'})


@to_json_decorator
@attr.s
class AccessRecord(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["access_record_id", "device_id", "access_time"])
    access_record_id = attr.ib(type=int, default=None, metadata={'json': 'access_record_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    device_id = attr.ib(type=int, default=None, metadata={'json': 'device_id'})
    is_clock_in = attr.ib(type=bool, default=None, metadata={'json': 'is_clock_in'})
    access_time = attr.ib(type=int, default=None, metadata={'json': 'access_time'})
    access_type = attr.ib(type=str, default=None, metadata={'json': 'access_type'})
    access_data = attr.ib(type=str, default=None, metadata={'json': 'access_data'})
    is_door_open = attr.ib(type=bool, default=None, metadata={'json': 'is_door_open'})


@attr.s
class AccessRecordListResult(object):
    items = attr.ib(type=List[AccessRecord], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})





@attr.s
class DeviceListResult(object):
    items = attr.ib(type=List[Device], default=None, metadata={'json': 'items'})





@attr.s
class UserGetResult(object):
    user = attr.ib(type=User, default=None, metadata={'json': 'user'})



@attr.s
class UserListResult(object):
    items = attr.ib(type=List[User], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})






@attr.s
class AccessRecordCreatedEventData(object):
    access_record_id = attr.ib(type=str, default=None, metadata={'json': 'access_record_id'})
    user_id = attr.ib(type=UserId, default=None, metadata={'json': 'user_id'})
    device_id = attr.ib(type=str, default=None, metadata={'json': 'device_id'})
    is_clock_in = attr.ib(type=bool, default=None, metadata={'json': 'is_clock_in'})
    is_door_open = attr.ib(type=bool, default=None, metadata={'json': 'is_door_open'})
    access_time = attr.ib(type=str, default=None, metadata={'json': 'access_time'})


@attr.s
class AccessRecordCreatedEvent(BaseEventV2):
    event = attr.ib(type=AccessRecordCreatedEventData, default=None)



@attr.s
class UserUpdatedEventData(object):
    user_id = attr.ib(type=UserId, default=None, metadata={'json': 'user_id'})
    card = attr.ib(type=int, default=None, metadata={'json': 'card'})
    face_uploaded = attr.ib(type=bool, default=None, metadata={'json': 'face_uploaded'})


@attr.s
class UserUpdatedEvent(BaseEventV2):
    event = attr.ib(type=UserUpdatedEventData, default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
from ....event.model.event import *
import attr




@to_json_decorator
@attr.s
class UserId(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})


@to_json_decorator
@attr.s
class EventAwemeUser(object):
    user_id = attr.ib(type=UserId, default=None, metadata={'json': 'user_id'})
    aweme_user_id = attr.ib(type=str, default=None, metadata={'json': 'aweme_user_id'})
    is_binded = attr.ib(type=bool, default=None, metadata={'json': 'is_binded'})


@to_json_decorator
@attr.s
class AwemeUser(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["aweme_user_id"])
    aweme_user_id = attr.ib(type=int, default=None, metadata={'json': 'aweme_user_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    is_binded = attr.ib(type=bool, default=None, metadata={'json': 'is_binded'})




@attr.s
class AwemeUserGetBindInfoResult(object):
    aweme_user = attr.ib(type=AwemeUser, default=None, metadata={'json': 'aweme_user'})


@attr.s
class AwemeUserBindedAccountEventData(object):
    event_aweme_user = attr.ib(type=EventAwemeUser, default=None, metadata={'json': 'event_aweme_user'})


@attr.s
class AwemeUserBindedAccountEvent(BaseEventV2):
    event = attr.ib(type=AwemeUserBindedAccountEventData, default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
from ....event.model.event import *
import attr




@to_json_decorator
@attr.s
class Href(object):
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})


@to_json_decorator
@attr.s
class Origin(object):
    platform_i18n_name = attr.ib(type=str, default=None, metadata={'json': 'platform_i18n_name'})
    href = attr.ib(type=Href, default=None, metadata={'json': 'href'})


@to_json_decorator
@attr.s
class Due(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["time"])
    time = attr.ib(type=int, default=None, metadata={'json': 'time'})
    timezone = attr.ib(type=str, default=None, metadata={'json': 'timezone'})
    is_all_day = attr.ib(type=bool, default=None, metadata={'json': 'is_all_day'})


@to_json_decorator
@attr.s
class Task(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["complete_time", "create_time", "update_time"])
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    summary = attr.ib(type=str, default=None, metadata={'json': 'summary'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    complete_time = attr.ib(type=int, default=None, metadata={'json': 'complete_time'})
    creator_id = attr.ib(type=str, default=None, metadata={'json': 'creator_id'})
    extra = attr.ib(type=str, default=None, metadata={'json': 'extra'})
    create_time = attr.ib(type=int, default=None, metadata={'json': 'create_time'})
    update_time = attr.ib(type=int, default=None, metadata={'json': 'update_time'})
    due = attr.ib(type=Due, default=None, metadata={'json': 'due'})
    origin = attr.ib(type=Origin, default=None, metadata={'json': 'origin'})
    can_edit = attr.ib(type=bool, default=None, metadata={'json': 'can_edit'})
    custom = attr.ib(type=str, default=None, metadata={'json': 'custom'})


@to_json_decorator
@attr.s
class Collaborator(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})


@to_json_decorator
@attr.s
class Comment(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["parent_id", "id"])
    content = attr.ib(type=str, default=None, metadata={'json': 'content'})
    parent_id = attr.ib(type=int, default=None, metadata={'json': 'parent_id'})
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})


@to_json_decorator
@attr.s
class Follower(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})


@to_json_decorator
@attr.s
class Reminder(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["id"])
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})
    relative_fire_minute = attr.ib(type=int, default=None, metadata={'json': 'relative_fire_minute'})






@attr.s
class TaskCreateResult(object):
    task = attr.ib(type=Task, default=None, metadata={'json': 'task'})





@attr.s
class TaskGetResult(object):
    task = attr.ib(type=Task, default=None, metadata={'json': 'task'})


@to_json_decorator
@attr.s
class TaskPatchReqBody(object):
    task = attr.ib(type=Task, default=None, metadata={'json': 'task'})
    update_fields = attr.ib(type=List[str], default=None, metadata={'json': 'update_fields'})


@attr.s
class TaskPatchResult(object):
    task = attr.ib(type=Task, default=None, metadata={'json': 'task'})





@attr.s
class TaskCollaboratorCreateResult(object):
    collaborator = attr.ib(type=Collaborator, default=None, metadata={'json': 'collaborator'})





@attr.s
class TaskCollaboratorListResult(object):
    items = attr.ib(type=List[Collaborator], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})



@attr.s
class TaskCommentCreateResult(object):
    comment = attr.ib(type=Comment, default=None, metadata={'json': 'comment'})





@attr.s
class TaskCommentGetResult(object):
    comment = attr.ib(type=Comment, default=None, metadata={'json': 'comment'})


@to_json_decorator
@attr.s
class TaskCommentUpdateReqBody(object):
    content = attr.ib(type=str, default=None, metadata={'json': 'content'})


@attr.s
class TaskCommentUpdateResult(object):
    comment = attr.ib(type=Comment, default=None, metadata={'json': 'comment'})



@attr.s
class TaskFollowerCreateResult(object):
    follower = attr.ib(type=Follower, default=None, metadata={'json': 'follower'})





@attr.s
class TaskFollowerListResult(object):
    items = attr.ib(type=List[Follower], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})



@attr.s
class TaskReminderCreateResult(object):
    reminder = attr.ib(type=Reminder, default=None, metadata={'json': 'reminder'})





@attr.s
class TaskReminderListResult(object):
    items = attr.ib(type=List[Reminder], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})


@attr.s
class TaskUpdatedEventData(object):
    task_id = attr.ib(type=str, default=None, metadata={'json': 'task_id'})
    obj_type = attr.ib(type=int, default=None, metadata={'json': 'obj_type'})


@attr.s
class TaskUpdatedEvent(BaseEventV2):
    event = attr.ib(type=TaskUpdatedEventData, default=None)



@attr.s
class TaskCommentUpdatedEventData(object):
    task_id = attr.ib(type=str, default=None, metadata={'json': 'task_id'})
    comment_id = attr.ib(type=str, default=None, metadata={'json': 'comment_id'})
    parent_id = attr.ib(type=str, default=None, metadata={'json': 'parent_id'})
    obj_type = attr.ib(type=int, default=None, metadata={'json': 'obj_type'})


@attr.s
class TaskCommentUpdatedEvent(BaseEventV2):
    event = attr.ib(type=TaskCommentUpdatedEventData, default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class View(object):
    view_type = attr.ib(type=int, default=None, metadata={'json': 'view_type'})


@to_json_decorator
@attr.s
class UpdateTablePropertyRequest(object):
    column_width = attr.ib(type=int, default=None, metadata={'json': 'column_width'})
    column_index = attr.ib(type=int, default=None, metadata={'json': 'column_index'})


@to_json_decorator
@attr.s
class UpdateGridColumnWidthRatioRequest(object):
    width_ratios = attr.ib(type=List[int], default=None, metadata={'json': 'width_ratios'})


@to_json_decorator
@attr.s
class UnmergeTableCellsRequest(object):
    row_index = attr.ib(type=int, default=None, metadata={'json': 'row_index'})
    column_index = attr.ib(type=int, default=None, metadata={'json': 'column_index'})


@to_json_decorator
@attr.s
class UndefinedElement(object):
    pass


@to_json_decorator
@attr.s
class Undefined(object):
    pass


@to_json_decorator
@attr.s
class TextStyle(object):
    align = attr.ib(type=int, default=None, metadata={'json': 'align'})
    done = attr.ib(type=bool, default=None, metadata={'json': 'done'})
    folded = attr.ib(type=bool, default=None, metadata={'json': 'folded'})
    language = attr.ib(type=int, default=None, metadata={'json': 'language'})
    wrap = attr.ib(type=bool, default=None, metadata={'json': 'wrap'})


@to_json_decorator
@attr.s
class UpdateTextStyleRequest(object):
    style = attr.ib(type=TextStyle, default=None, metadata={'json': 'style'})
    fields = attr.ib(type=List[int], default=None, metadata={'json': 'fields'})


@to_json_decorator
@attr.s
class TableMergeInfo(object):
    row_span = attr.ib(type=int, default=None, metadata={'json': 'row_span'})
    col_span = attr.ib(type=int, default=None, metadata={'json': 'col_span'})


@to_json_decorator
@attr.s
class TableProperty(object):
    row_size = attr.ib(type=int, default=None, metadata={'json': 'row_size'})
    column_size = attr.ib(type=int, default=None, metadata={'json': 'column_size'})
    column_width = attr.ib(type=List[int], default=None, metadata={'json': 'column_width'})
    merge_info = attr.ib(type=List[TableMergeInfo], default=None, metadata={'json': 'merge_info'})


@to_json_decorator
@attr.s
class Table(object):
    cells = attr.ib(type=List[str], default=None, metadata={'json': 'cells'})
    property = attr.ib(type=TableProperty, default=None, metadata={'json': 'property'})


@to_json_decorator
@attr.s
class TableCell(object):
    pass


@to_json_decorator
@attr.s
class Sheet(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    row_size = attr.ib(type=int, default=None, metadata={'json': 'row_size'})
    column_size = attr.ib(type=int, default=None, metadata={'json': 'column_size'})


@to_json_decorator
@attr.s
class ReplaceImageRequest(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})


@to_json_decorator
@attr.s
class ReplaceFileRequest(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})


@to_json_decorator
@attr.s
class Reminder(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["expire_time", "notify_time"])
    create_user_id = attr.ib(type=str, default=None, metadata={'json': 'create_user_id'})
    is_notify = attr.ib(type=bool, default=None, metadata={'json': 'is_notify'})
    is_whole_day = attr.ib(type=bool, default=None, metadata={'json': 'is_whole_day'})
    expire_time = attr.ib(type=int, default=None, metadata={'json': 'expire_time'})
    notify_time = attr.ib(type=int, default=None, metadata={'json': 'notify_time'})


@to_json_decorator
@attr.s
class Mindnote(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})


@to_json_decorator
@attr.s
class MergeTableCellsRequest(object):
    row_start_index = attr.ib(type=int, default=None, metadata={'json': 'row_start_index'})
    row_end_index = attr.ib(type=int, default=None, metadata={'json': 'row_end_index'})
    column_start_index = attr.ib(type=int, default=None, metadata={'json': 'column_start_index'})
    column_end_index = attr.ib(type=int, default=None, metadata={'json': 'column_end_index'})


@to_json_decorator
@attr.s
class MentionUser(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})


@to_json_decorator
@attr.s
class MentionDoc(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    obj_type = attr.ib(type=int, default=None, metadata={'json': 'obj_type'})
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})


@to_json_decorator
@attr.s
class Link(object):
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})


@to_json_decorator
@attr.s
class TextElementStyle(object):
    bold = attr.ib(type=bool, default=None, metadata={'json': 'bold'})
    italic = attr.ib(type=bool, default=None, metadata={'json': 'italic'})
    strikethrough = attr.ib(type=bool, default=None, metadata={'json': 'strikethrough'})
    underline = attr.ib(type=bool, default=None, metadata={'json': 'underline'})
    inline_code = attr.ib(type=bool, default=None, metadata={'json': 'inline_code'})
    background_color = attr.ib(type=int, default=None, metadata={'json': 'background_color'})
    text_color = attr.ib(type=int, default=None, metadata={'json': 'text_color'})
    link = attr.ib(type=Link, default=None, metadata={'json': 'link'})


@to_json_decorator
@attr.s
class TextRun(object):
    content = attr.ib(type=str, default=None, metadata={'json': 'content'})
    text_element_style = attr.ib(type=TextElementStyle, default=None, metadata={'json': 'text_element_style'})


@to_json_decorator
@attr.s
class Isv(object):
    component_id = attr.ib(type=str, default=None, metadata={'json': 'component_id'})
    component_type_id = attr.ib(type=str, default=None, metadata={'json': 'component_type_id'})


@to_json_decorator
@attr.s
class InsertTableRowRequest(object):
    row_index = attr.ib(type=int, default=None, metadata={'json': 'row_index'})


@to_json_decorator
@attr.s
class InsertTableColumnRequest(object):
    column_index = attr.ib(type=int, default=None, metadata={'json': 'column_index'})


@to_json_decorator
@attr.s
class InsertGridColumnRequest(object):
    column_index = attr.ib(type=int, default=None, metadata={'json': 'column_index'})


@to_json_decorator
@attr.s
class InlineFile(object):
    file_token = attr.ib(type=str, default=None, metadata={'json': 'file_token'})
    source_block_id = attr.ib(type=str, default=None, metadata={'json': 'source_block_id'})


@to_json_decorator
@attr.s
class InlineBlock(object):
    block_id = attr.ib(type=str, default=None, metadata={'json': 'block_id'})


@to_json_decorator
@attr.s
class TextElement(object):
    text_run = attr.ib(type=TextRun, default=None, metadata={'json': 'text_run'})
    mention_user = attr.ib(type=MentionUser, default=None, metadata={'json': 'mention_user'})
    mention_doc = attr.ib(type=MentionDoc, default=None, metadata={'json': 'mention_doc'})
    reminder = attr.ib(type=Reminder, default=None, metadata={'json': 'reminder'})
    file = attr.ib(type=InlineFile, default=None, metadata={'json': 'file'})
    undefined = attr.ib(type=UndefinedElement, default=None, metadata={'json': 'undefined'})
    inline_block = attr.ib(type=InlineBlock, default=None, metadata={'json': 'inline_block'})


@to_json_decorator
@attr.s
class UpdateTextElementsRequest(object):
    elements = attr.ib(type=List[TextElement], default=None, metadata={'json': 'elements'})


@to_json_decorator
@attr.s
class Text(object):
    style = attr.ib(type=TextStyle, default=None, metadata={'json': 'style'})
    elements = attr.ib(type=List[TextElement], default=None, metadata={'json': 'elements'})


@to_json_decorator
@attr.s
class Image(object):
    width = attr.ib(type=int, default=None, metadata={'json': 'width'})
    height = attr.ib(type=int, default=None, metadata={'json': 'height'})
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})


@to_json_decorator
@attr.s
class IframeComponent(object):
    iframe_type = attr.ib(type=int, default=None, metadata={'json': 'iframe_type'})
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})


@to_json_decorator
@attr.s
class Iframe(object):
    component = attr.ib(type=IframeComponent, default=None, metadata={'json': 'component'})


@to_json_decorator
@attr.s
class GridColumn(object):
    width_ratio = attr.ib(type=int, default=None, metadata={'json': 'width_ratio'})


@to_json_decorator
@attr.s
class Grid(object):
    column_size = attr.ib(type=int, default=None, metadata={'json': 'column_size'})


@to_json_decorator
@attr.s
class File(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class Divider(object):
    pass


@to_json_decorator
@attr.s
class Diagram(object):
    diagram_type = attr.ib(type=int, default=None, metadata={'json': 'diagram_type'})


@to_json_decorator
@attr.s
class DeleteTableRowsRequest(object):
    row_start_index = attr.ib(type=int, default=None, metadata={'json': 'row_start_index'})
    row_end_index = attr.ib(type=int, default=None, metadata={'json': 'row_end_index'})


@to_json_decorator
@attr.s
class DeleteTableColumnsRequest(object):
    column_start_index = attr.ib(type=int, default=None, metadata={'json': 'column_start_index'})
    column_end_index = attr.ib(type=int, default=None, metadata={'json': 'column_end_index'})


@to_json_decorator
@attr.s
class DeleteGridColumnRequest(object):
    column_index = attr.ib(type=int, default=None, metadata={'json': 'column_index'})


@to_json_decorator
@attr.s
class UpdateBlockRequest(object):
    update_text_elements = attr.ib(type=UpdateTextElementsRequest, default=None, metadata={'json': 'update_text_elements'})
    update_text_style = attr.ib(type=UpdateTextStyleRequest, default=None, metadata={'json': 'update_text_style'})
    update_table_property = attr.ib(type=UpdateTablePropertyRequest, default=None, metadata={'json': 'update_table_property'})
    insert_table_row = attr.ib(type=InsertTableRowRequest, default=None, metadata={'json': 'insert_table_row'})
    insert_table_column = attr.ib(type=InsertTableColumnRequest, default=None, metadata={'json': 'insert_table_column'})
    delete_table_rows = attr.ib(type=DeleteTableRowsRequest, default=None, metadata={'json': 'delete_table_rows'})
    delete_table_columns = attr.ib(type=DeleteTableColumnsRequest, default=None, metadata={'json': 'delete_table_columns'})
    merge_table_cells = attr.ib(type=MergeTableCellsRequest, default=None, metadata={'json': 'merge_table_cells'})
    unmerge_table_cells = attr.ib(type=UnmergeTableCellsRequest, default=None, metadata={'json': 'unmerge_table_cells'})
    insert_grid_column = attr.ib(type=InsertGridColumnRequest, default=None, metadata={'json': 'insert_grid_column'})
    delete_grid_column = attr.ib(type=DeleteGridColumnRequest, default=None, metadata={'json': 'delete_grid_column'})
    update_grid_column_width_ratio = attr.ib(type=UpdateGridColumnWidthRatioRequest, default=None, metadata={'json': 'update_grid_column_width_ratio'})
    replace_image = attr.ib(type=ReplaceImageRequest, default=None, metadata={'json': 'replace_image'})
    replace_file = attr.ib(type=ReplaceFileRequest, default=None, metadata={'json': 'replace_file'})
    block_id = attr.ib(type=str, default=None, metadata={'json': 'block_id'})


@to_json_decorator
@attr.s
class ChatCard(object):
    __int_to_string_fields__ = attr.ib(type=List[str], default=["chat_id"])
    chat_id = attr.ib(type=int, default=None, metadata={'json': 'chat_id'})
    align = attr.ib(type=int, default=None, metadata={'json': 'align'})


@to_json_decorator
@attr.s
class Callout(object):
    background_color = attr.ib(type=int, default=None, metadata={'json': 'background_color'})
    border_color = attr.ib(type=int, default=None, metadata={'json': 'border_color'})
    text_color = attr.ib(type=int, default=None, metadata={'json': 'text_color'})
    emoji_id = attr.ib(type=str, default=None, metadata={'json': 'emoji_id'})


@to_json_decorator
@attr.s
class Bitable(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    view_type = attr.ib(type=int, default=None, metadata={'json': 'view_type'})


@to_json_decorator
@attr.s
class Block(object):
    block_id = attr.ib(type=str, default=None, metadata={'json': 'block_id'})
    parent_id = attr.ib(type=str, default=None, metadata={'json': 'parent_id'})
    children = attr.ib(type=List[str], default=None, metadata={'json': 'children'})
    block_type = attr.ib(type=int, default=None, metadata={'json': 'block_type'})
    page = attr.ib(type=Text, default=None, metadata={'json': 'page'})
    text = attr.ib(type=Text, default=None, metadata={'json': 'text'})
    heading1 = attr.ib(type=Text, default=None, metadata={'json': 'heading1'})
    heading2 = attr.ib(type=Text, default=None, metadata={'json': 'heading2'})
    heading3 = attr.ib(type=Text, default=None, metadata={'json': 'heading3'})
    heading4 = attr.ib(type=Text, default=None, metadata={'json': 'heading4'})
    heading5 = attr.ib(type=Text, default=None, metadata={'json': 'heading5'})
    heading6 = attr.ib(type=Text, default=None, metadata={'json': 'heading6'})
    heading7 = attr.ib(type=Text, default=None, metadata={'json': 'heading7'})
    heading8 = attr.ib(type=Text, default=None, metadata={'json': 'heading8'})
    heading9 = attr.ib(type=Text, default=None, metadata={'json': 'heading9'})
    bullet = attr.ib(type=Text, default=None, metadata={'json': 'bullet'})
    ordered = attr.ib(type=Text, default=None, metadata={'json': 'ordered'})
    code = attr.ib(type=Text, default=None, metadata={'json': 'code'})
    quote = attr.ib(type=Text, default=None, metadata={'json': 'quote'})
    equation = attr.ib(type=Text, default=None, metadata={'json': 'equation'})
    todo = attr.ib(type=Text, default=None, metadata={'json': 'todo'})
    bitable = attr.ib(type=Bitable, default=None, metadata={'json': 'bitable'})
    callout = attr.ib(type=Callout, default=None, metadata={'json': 'callout'})
    chat_card = attr.ib(type=ChatCard, default=None, metadata={'json': 'chat_card'})
    diagram = attr.ib(type=Diagram, default=None, metadata={'json': 'diagram'})
    divider = attr.ib(type=Divider, default=None, metadata={'json': 'divider'})
    file = attr.ib(type=File, default=None, metadata={'json': 'file'})
    grid = attr.ib(type=Grid, default=None, metadata={'json': 'grid'})
    grid_column = attr.ib(type=GridColumn, default=None, metadata={'json': 'grid_column'})
    iframe = attr.ib(type=Iframe, default=None, metadata={'json': 'iframe'})
    image = attr.ib(type=Image, default=None, metadata={'json': 'image'})
    isv = attr.ib(type=Isv, default=None, metadata={'json': 'isv'})
    mindnote = attr.ib(type=Mindnote, default=None, metadata={'json': 'mindnote'})
    sheet = attr.ib(type=Sheet, default=None, metadata={'json': 'sheet'})
    table = attr.ib(type=Table, default=None, metadata={'json': 'table'})
    table_cell = attr.ib(type=TableCell, default=None, metadata={'json': 'table_cell'})
    view = attr.ib(type=View, default=None, metadata={'json': 'view'})
    undefined = attr.ib(type=Undefined, default=None, metadata={'json': 'undefined'})


@to_json_decorator
@attr.s
class Document(object):
    document_id = attr.ib(type=str, default=None, metadata={'json': 'document_id'})
    revision_id = attr.ib(type=int, default=None, metadata={'json': 'revision_id'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})



@to_json_decorator
@attr.s
class DocumentCreateReqBody(object):
    folder_token = attr.ib(type=str, default=None, metadata={'json': 'folder_token'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})


@attr.s
class DocumentCreateResult(object):
    document = attr.ib(type=Document, default=None, metadata={'json': 'document'})



@attr.s
class DocumentGetResult(object):
    document = attr.ib(type=Document, default=None, metadata={'json': 'document'})



@attr.s
class DocumentRawContentResult(object):
    content = attr.ib(type=str, default=None, metadata={'json': 'content'})


@to_json_decorator
@attr.s
class DocumentBlockBatchUpdateReqBody(object):
    requests = attr.ib(type=List[UpdateBlockRequest], default=None, metadata={'json': 'requests'})


@attr.s
class DocumentBlockBatchUpdateResult(object):
    blocks = attr.ib(type=List[Block], default=None, metadata={'json': 'blocks'})
    document_revision_id = attr.ib(type=int, default=None, metadata={'json': 'document_revision_id'})
    client_token = attr.ib(type=str, default=None, metadata={'json': 'client_token'})



@attr.s
class DocumentBlockGetResult(object):
    block = attr.ib(type=Block, default=None, metadata={'json': 'block'})



@attr.s
class DocumentBlockListResult(object):
    items = attr.ib(type=List[Block], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})



@attr.s
class DocumentBlockPatchResult(object):
    block = attr.ib(type=Block, default=None, metadata={'json': 'block'})
    document_revision_id = attr.ib(type=int, default=None, metadata={'json': 'document_revision_id'})
    client_token = attr.ib(type=str, default=None, metadata={'json': 'client_token'})


@to_json_decorator
@attr.s
class DocumentBlockChildrenBatchDeleteReqBody(object):
    start_index = attr.ib(type=int, default=None, metadata={'json': 'start_index'})
    end_index = attr.ib(type=int, default=None, metadata={'json': 'end_index'})


@attr.s
class DocumentBlockChildrenBatchDeleteResult(object):
    document_revision_id = attr.ib(type=int, default=None, metadata={'json': 'document_revision_id'})
    client_token = attr.ib(type=str, default=None, metadata={'json': 'client_token'})


@to_json_decorator
@attr.s
class DocumentBlockChildrenCreateReqBody(object):
    children = attr.ib(type=List[Block], default=None, metadata={'json': 'children'})
    index = attr.ib(type=int, default=None, metadata={'json': 'index'})


@attr.s
class DocumentBlockChildrenCreateResult(object):
    children = attr.ib(type=List[Block], default=None, metadata={'json': 'children'})
    document_revision_id = attr.ib(type=int, default=None, metadata={'json': 'document_revision_id'})
    client_token = attr.ib(type=str, default=None, metadata={'json': 'client_token'})



@attr.s
class DocumentBlockChildrenGetResult(object):
    items = attr.ib(type=List[Block], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})


# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.tasks = TaskService(self)
        self.task_comments = TaskCommentService(self)
        self.task_collaborators = TaskCollaboratorService(self)
        self.task_followers = TaskFollowerService(self)
        self.task_reminders = TaskReminderService(self)
        



class TaskService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def complete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskCompleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCompleteReqCall(self, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Task, str, int) -> TaskCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskDeleteReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskGetReqCall(self, request_opts=request_opts)

    def patch(self, body, tenant_key=None, timeout=None):
        # type: (TaskPatchReqBody, str, int) -> TaskPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskPatchReqCall(self, body, request_opts=request_opts)

    def uncomplete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskUncompleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskUncompleteReqCall(self, request_opts=request_opts)


class TaskCommentService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Comment, str, int) -> TaskCommentCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCommentCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskCommentDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCommentDeleteReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskCommentGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCommentGetReqCall(self, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (TaskCommentUpdateReqBody, str, int) -> TaskCommentUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCommentUpdateReqCall(self, body, request_opts=request_opts)


class TaskCollaboratorService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Collaborator, str, int) -> TaskCollaboratorCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCollaboratorCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskCollaboratorDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCollaboratorDeleteReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskCollaboratorListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskCollaboratorListReqCall(self, request_opts=request_opts)


class TaskFollowerService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Follower, str, int) -> TaskFollowerCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskFollowerCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskFollowerDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskFollowerDeleteReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskFollowerListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskFollowerListReqCall(self, request_opts=request_opts)


class TaskReminderService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, timeout=None):
        # type: (Reminder, str, int) -> TaskReminderCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskReminderCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskReminderDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskReminderDeleteReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> TaskReminderListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return TaskReminderListReqCall(self, request_opts=request_opts)



class TaskCompleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCompleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/complete', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskService, Task, List[Any]) -> None

        self.service = service
        self.body = body
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskDeleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskGetReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=TaskGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskService, TaskPatchReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskPatchReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskPatchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskPatchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskPatchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskUncompleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskUncompleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/uncomplete', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCollaboratorCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskCollaboratorService, Collaborator, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCollaboratorCreateReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskCollaboratorCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCollaboratorCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/collaborators', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskCollaboratorCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCollaboratorDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskCollaboratorService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCollaboratorDeleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_collaborator_id(self, collaborator_id):
        # type: (str) -> TaskCollaboratorDeleteReqCall
        self.path_params['collaborator_id'] = collaborator_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/collaborators/:collaborator_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCollaboratorListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskCollaboratorService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCollaboratorListReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_page_size(self, page_size):
        # type: (int) -> TaskCollaboratorListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> TaskCollaboratorListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskCollaboratorListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCollaboratorListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/collaborators', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=TaskCollaboratorListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCommentCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskCommentService, Comment, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCommentCreateReqCall
        self.path_params['task_id'] = task_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCommentCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/comments', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskCommentCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCommentDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskCommentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCommentDeleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_comment_id(self, comment_id):
        # type: (int) -> TaskCommentDeleteReqCall
        self.path_params['comment_id'] = comment_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/comments/:comment_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCommentGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskCommentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCommentGetReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_comment_id(self, comment_id):
        # type: (int) -> TaskCommentGetReqCall
        self.path_params['comment_id'] = comment_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCommentGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/comments/:comment_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=TaskCommentGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskCommentUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskCommentService, TaskCommentUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskCommentUpdateReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_comment_id(self, comment_id):
        # type: (int) -> TaskCommentUpdateReqCall
        self.path_params['comment_id'] = comment_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskCommentUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/comments/:comment_id', 'PUT', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskCommentUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskFollowerCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskFollowerService, Follower, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskFollowerCreateReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskFollowerCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskFollowerCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/followers', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskFollowerCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskFollowerDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskFollowerService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskFollowerDeleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_follower_id(self, follower_id):
        # type: (str) -> TaskFollowerDeleteReqCall
        self.path_params['follower_id'] = follower_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/followers/:follower_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskFollowerListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskFollowerService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskFollowerListReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_page_size(self, page_size):
        # type: (int) -> TaskFollowerListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> TaskFollowerListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> TaskFollowerListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskFollowerListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/followers', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=TaskFollowerListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskReminderCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (TaskReminderService, Reminder, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskReminderCreateReqCall
        self.path_params['task_id'] = task_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskReminderCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/reminders', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=TaskReminderCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskReminderDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskReminderService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskReminderDeleteReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_reminder_id(self, reminder_id):
        # type: (str) -> TaskReminderDeleteReqCall
        self.path_params['reminder_id'] = reminder_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[None]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/reminders/:reminder_id', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT],
                        None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class TaskReminderListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (TaskReminderService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_task_id(self, task_id):
        # type: (str) -> TaskReminderListReqCall
        self.path_params['task_id'] = task_id
        return self

    def set_page_size(self, page_size):
        # type: (int) -> TaskReminderListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> TaskReminderListReqCall
        self.query_params['page_token'] = page_token
        return self

    def do(self):
        # type: () -> APIResponse[Type[TaskReminderListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/task/v1/tasks/:task_id/reminders', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                        None, output_class=TaskReminderListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.documents = DocumentService(self)
        self.document_blocks = DocumentBlockService(self)
        self.document_block_childrens = DocumentBlockChildrenService(self)
        



class DocumentService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def create(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocumentCreateReqBody, str, str, int) -> DocumentCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentCreateReqCall(self, body, request_opts=request_opts)

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocumentGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentGetReqCall(self, request_opts=request_opts)

    def raw_content(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocumentRawContentReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentRawContentReqCall(self, request_opts=request_opts)


class DocumentBlockService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_update(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocumentBlockBatchUpdateReqBody, str, str, int) -> DocumentBlockBatchUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockBatchUpdateReqCall(self, body, request_opts=request_opts)

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocumentBlockGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockGetReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocumentBlockListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockListReqCall(self, request_opts=request_opts)

    def patch(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (UpdateBlockRequest, str, str, int) -> DocumentBlockPatchReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockPatchReqCall(self, body, request_opts=request_opts)


class DocumentBlockChildrenService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_delete(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocumentBlockChildrenBatchDeleteReqBody, str, str, int) -> DocumentBlockChildrenBatchDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockChildrenBatchDeleteReqCall(self, body, request_opts=request_opts)

    def create(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocumentBlockChildrenCreateReqBody, str, str, int) -> DocumentBlockChildrenCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockChildrenCreateReqCall(self, body, request_opts=request_opts)

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocumentBlockChildrenGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocumentBlockChildrenGetReqCall(self, request_opts=request_opts)



class DocumentCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocumentService, DocumentCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> APIResponse[Type[DocumentCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        req = APIRequest('/open-apis/docx/v1/documents', 'POST', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocumentCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocumentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentGetReqCall
        self.path_params['document_id'] = document_id
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DocumentGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentRawContentReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocumentService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentRawContentReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_lang(self, lang):
        # type: (int) -> DocumentRawContentReqCall
        self.query_params['lang'] = lang
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentRawContentResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/raw_content', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DocumentRawContentResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockBatchUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocumentBlockService, DocumentBlockBatchUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockBatchUpdateReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockBatchUpdateReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_client_token(self, client_token):
        # type: (str) -> DocumentBlockBatchUpdateReqCall
        self.query_params['client_token'] = client_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockBatchUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockBatchUpdateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/batch_update', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocumentBlockBatchUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocumentBlockService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockGetReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_block_id(self, block_id):
        # type: (str) -> DocumentBlockGetReqCall
        self.path_params['block_id'] = block_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockGetReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/:block_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DocumentBlockGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocumentBlockService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockListReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DocumentBlockListReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DocumentBlockListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockListReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockListReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockListResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DocumentBlockListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockPatchReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocumentBlockService, UpdateBlockRequest, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockPatchReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_block_id(self, block_id):
        # type: (str) -> DocumentBlockPatchReqCall
        self.path_params['block_id'] = block_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockPatchReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_client_token(self, client_token):
        # type: (str) -> DocumentBlockPatchReqCall
        self.query_params['client_token'] = client_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockPatchReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockPatchResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/:block_id', 'PATCH', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocumentBlockPatchResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockChildrenBatchDeleteReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocumentBlockChildrenService, DocumentBlockChildrenBatchDeleteReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockChildrenBatchDeleteReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_block_id(self, block_id):
        # type: (str) -> DocumentBlockChildrenBatchDeleteReqCall
        self.path_params['block_id'] = block_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockChildrenBatchDeleteReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_client_token(self, client_token):
        # type: (str) -> DocumentBlockChildrenBatchDeleteReqCall
        self.query_params['client_token'] = client_token
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockChildrenBatchDeleteResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/:block_id/children/batch_delete', 'DELETE', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocumentBlockChildrenBatchDeleteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockChildrenCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocumentBlockChildrenService, DocumentBlockChildrenCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockChildrenCreateReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_block_id(self, block_id):
        # type: (str) -> DocumentBlockChildrenCreateReqCall
        self.path_params['block_id'] = block_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockChildrenCreateReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_client_token(self, client_token):
        # type: (str) -> DocumentBlockChildrenCreateReqCall
        self.query_params['client_token'] = client_token
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockChildrenCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockChildrenCreateResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/:block_id/children', 'POST', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        self.body, output_class=DocumentBlockChildrenCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocumentBlockChildrenGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocumentBlockChildrenService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_document_id(self, document_id):
        # type: (str) -> DocumentBlockChildrenGetReqCall
        self.path_params['document_id'] = document_id
        return self

    def set_block_id(self, block_id):
        # type: (str) -> DocumentBlockChildrenGetReqCall
        self.path_params['block_id'] = block_id
        return self

    def set_document_revision_id(self, document_revision_id):
        # type: (int) -> DocumentBlockChildrenGetReqCall
        self.query_params['document_revision_id'] = document_revision_id
        return self

    def set_page_token(self, page_token):
        # type: (str) -> DocumentBlockChildrenGetReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> DocumentBlockChildrenGetReqCall
        self.query_params['page_size'] = page_size
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> DocumentBlockChildrenGetReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[DocumentBlockChildrenGetResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/docx/v1/documents/:document_id/blocks/:block_id/children', 'GET', [ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER],
                        None, output_class=DocumentBlockChildrenGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request as APIRequest, Response as APIResponse, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.application_visibilitys = ApplicationVisibilityService(self)
        self.application_app_usages = ApplicationAppUsageService(self)
        



class ApplicationVisibilityService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service


class ApplicationAppUsageService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def overview(self, body, tenant_key=None, timeout=None):
        # type: (ApplicationAppUsageOverviewReqBody, str, int) -> ApplicationAppUsageOverviewReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return ApplicationAppUsageOverviewReqCall(self, body, request_opts=request_opts)



class ApplicationAppUsageOverviewReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (ApplicationAppUsageService, ApplicationAppUsageOverviewReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_id(self, app_id):
        # type: (str) -> ApplicationAppUsageOverviewReqCall
        self.path_params['app_id'] = app_id
        return self

    def set_department_id_type(self, department_id_type):
        # type: (str) -> ApplicationAppUsageOverviewReqCall
        self.query_params['department_id_type'] = department_id_type
        return self

    def do(self):
        # type: () -> APIResponse[Type[ApplicationAppUsageOverviewResult]]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = APIRequest('/open-apis/application/v6/applications/:app_id/app_usage/overview', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                        self.body, output_class=ApplicationAppUsageOverviewResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp

